# vim: set sw=4 ts=4 et nu:
#
# spec file for package latrace
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           latrace
Version:        0.5.11
Release:        13.7
Summary:        Trace Library Calls using LD_AUDIT
License:        GPL-3.0-or-later
Group:          System/Monitoring
URL:            http://people.redhat.com/jolsa/latrace/index.shtml
Source:         %{name}-%{version}.tar.xz
# Fresh config.guess and config.sub files
# wget -O config.guess 'http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.guess;hb=HEAD'
Source1:        config.guess
# wget -O config.sub 'http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.sub;hb=HEAD'
Source2:        config.sub
Source99:       latrace-rpmlintrc
Patch0:         reproducible.patch
Patch1:         latrace-0.5.11-fixes.diff
Patch2:         0001-make-Fixes-paraller-building-like-make-j16.patch
Patch3:         0002-stats-bugfix-use-timersub-and-timeradd.patch
Patch4:         0003-stats-report-zero-percents-instead-of-NaN.patch
Patch5:         0004-add-aarch64-and-ppc64le-support-to-audit.h.patch
Patch6:         latrace-PRINT-format.patch
Patch7:         ppc-fedora.patch
BuildRequires:  asciidoc
BuildRequires:  autoconf
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  xmlto

%description
latrace is a glibc 2.4+ LD_AUDIT frontend. It allows you to trace library calls
and get their statistics in a manner similar to the strace utility.

%prep
%setup -q
cp %{SOURCE1} %{SOURCE2} .
%patch0 -p1
%patch1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1

%build
autoconf
%configure --libdir=%{_libdir}/latrace
make V=1

%install
%make_install V=1

%files
%license COPYING
%doc ChangeLog README TODO ReleaseNotes
%config %dir %{_sysconfdir}/latrace.d
%config %dir %{_sysconfdir}/latrace.d/headers
%config %{_sysconfdir}/latrace.d/*.conf
%config %{_sysconfdir}/latrace.d/headers/*.h
%ifarch x86_64
%config %dir %{_sysconfdir}/latrace.d/headers/sysdeps
%config %dir %{_sysconfdir}/latrace.d/headers/sysdeps/*
%config %{_sysconfdir}/latrace.d/headers/sysdeps/*/*.h
%endif
%{_bindir}/latrace
%{_bindir}/latrace-ctl
%dir %{_libdir}/latrace
%{_libdir}/latrace/libltaudit.so.%{version}
%{_mandir}/man1/latrace.1%{?ext_man}

%changelog
* Thu Apr 21 2022 Fridrich Strba <fstrba@suse.com>
- Add config.sub and config.guess files to sources in order to fix
  generation of configure from configure.ac in Factory
- Fetch the tarball using source service, since the tarball does
  not exist any more on people.redhat.com
- Added patches:
  * 0001-make-Fixes-paraller-building-like-make-j16.patch:
    Upstream fix for highly parallel builds
  * 0002-stats-bugfix-use-timersub-and-timeradd.patch:
    Upstream commit to replace buggy tv_sub and tv_add by
    timersub and timeradd
  * 0003-stats-report-zero-percents-instead-of-NaN.patch:
    Upstream fix to report zero percent instead of NaN
  * 0004-add-aarch64-and-ppc64le-support-to-audit.h.patch:
    Upstream commit to add support for ppc64le and aarch64
    architectures
  * ppc-fedora.patch
  * latrace-PRINT-format.patch:
    Avoid a non-literal format string by using string token
    pasting
* Mon Sep 11 2017 jengelh@inai.de
- Drop old RPM constructs like %%clean or %%__-type indirections.
  Remove unnecessary ldconfig call.
* Tue Jul 25 2017 rguenther@suse.com
- Add latrace-0.5.11-fixes.diff to fix build after recent flex upgrade.
* Wed Apr 13 2016 bwiedemann@suse.com
- Add reproducible.patch to fix build-compare
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Wed Dec 19 2012 dvaleev@suse.com
- set Exclusive arch to x86 and ARM
* Thu Jun 28 2012 rguenther@suse.com
- Update to version 0.5.11
- Move private library to /usr/lib/latrace
- Change to SPDX licensing format.
- Remove not needed BuildRequires.
* Fri Jul 23 2010 pascal.bleser@opensuse.org
- initial package (0.5.9)
